@@ -104,8 +104,11 @@ function config_heat_dashboard {
     done
 
     config_dashboard "${ENABLE_HEAT:-no}" \
-        "${SITE_PACKAGES}/heat_dashboard/conf/heat_policy.json" \
-        "/etc/openstack-dashboard/heat_policy.json"
+        "${SITE_PACKAGES}/heat_dashboard/conf/heat_policy.yaml" \
+        "/etc/openstack-dashboard/heat_policy.yaml"
+    config_dashboard "${ENABLE_HEAT:-no}" \
+        "${SITE_PACKAGES}/heat_dashboard/conf/default_policies/heat.yaml" \
+        "/etc/openstack-dashboard/default_policies/heat.yaml"
 }
 
 function config_ironic_dashboard {
@@ -116,14 +119,6 @@ function config_ironic_dashboard {
     done
 }
 
-function config_karbor_dashboard {
-    for file in ${SITE_PACKAGES}/karbor_dashboard/enabled/_*[^__].py; do
-        config_dashboard "${ENABLE_KARBOR}" \
-            "${SITE_PACKAGES}/karbor_dashboard/enabled/${file##*/}" \
-            "${SITE_PACKAGES}/openstack_dashboard/local/enabled/${file##*/}"
-    done
-}
-
 function config_magnum_dashboard {
     for file in ${SITE_PACKAGES}/magnum_ui/enabled/_*[^__].py; do
         config_dashboard "${ENABLE_MAGNUM:-no}" \
@@ -138,6 +133,13 @@ function config_manila_ui {
             "${SITE_PACKAGES}/manila_ui/local/enabled/${file##*/}" \
             "${SITE_PACKAGES}/openstack_dashboard/local/enabled/${file##*/}"
     done
+
+    config_dashboard "${ENABLE_MANILA:-no}" \
+        "${SITE_PACKAGES}/manila_ui/conf/manila_policy.yaml" \
+        "/etc/openstack-dashboard/manila_policy.yaml"
+    config_dashboard "${ENABLE_MANILA:-no}" \
+        "${SITE_PACKAGES}/manila_ui/conf/default_policies/manila.yaml" \
+        "/etc/openstack-dashboard/default_policies/manila.yaml"
 }
 
 function config_masakari_dashboard {
@@ -196,14 +198,6 @@ function config_octavia_dashboard {
         "${SITE_PACKAGES}/openstack_dashboard/local/enabled/_1482_project_load_balancer_panel.py"
 }
 
-function config_qinling_dashboard {
-    for file in ${SITE_PACKAGES}/qinling_dashboard/enabled/_*[^__].py; do
-        config_dashboard "${ENABLE_QINLING}" \
-            "${SITE_PACKAGES}/qinling_dashboard/enabled/${file##*/}" \
-            "${SITE_PACKAGES}/openstack_dashboard/local/enabled/${file##*/}"
-    done
-}
-
 function config_sahara_dashboard {
     for file in ${SITE_PACKAGES}/sahara_dashboard/enabled/_*[^__].py; do
         config_dashboard "${ENABLE_SAHARA:-no}" \
@@ -212,22 +206,6 @@ function config_sahara_dashboard {
     done
 }
 
-function config_searchlight_ui {
-    for file in ${SITE_PACKAGES}/searchlight_ui/enabled/_*[^__].py; do
-        config_dashboard "${ENABLE_SEARCHLIGHT}" \
-            "${SITE_PACKAGES}/searchlight_ui/enabled/${file##*/}" \
-            "${SITE_PACKAGES}/openstack_dashboard/local/enabled/${file##*/}"
-    done
-
-    config_dashboard "${ENABLE_SEARCHLIGHT}" \
-        "${SITE_PACKAGES}/searchlight_ui/local_settings.d/_1001_search_settings.py" \
-        "${SITE_PACKAGES}/openstack_dashboard/local/local_settings.d/_1001_search_settings.py"
-
-    config_dashboard "${ENABLE_SEARCHLIGHT}" \
-        "${SITE_PACKAGES}/searchlight_ui/conf/searchlight_policy.json" \
-        "/etc/openstack-dashboard/searchlight_policy.json"
-}
-
 function config_senlin_dashboard {
     for file in ${SITE_PACKAGES}/senlin_dashboard/enabled/_*[^__].py; do
         config_dashboard "${ENABLE_SENLIN:-no}" \
@@ -284,14 +262,6 @@ function config_watcher_dashboard {
             "/etc/openstack-dashboard/watcher_policy.json"
 }
 
-function config_zaqar_dashboard {
-    for file in ${SITE_PACKAGES}/zaqar_ui/enabled/_*[^__].py; do
-        config_dashboard "${ENABLE_ZAQAR:-no}" \
-            "${SITE_PACKAGES}/zaqar_ui/enabled/${file##*/}" \
-            "${SITE_PACKAGES}/openstack_dashboard/local/enabled/${file##*/}"
-    done
-}
-
 function config_zun_dashboard {
     for file in ${SITE_PACKAGES}/zun_ui/enabled/_*[^__].py; do
         config_dashboard "${ENABLE_ZUN:-no}" \
@@ -328,7 +298,6 @@ config_designate_dashboard
 config_freezer_ui
 config_heat_dashboard
 config_ironic_dashboard
-config_karbor_dashboard
 config_magnum_dashboard
 config_manila_ui
 config_masakari_dashboard
@@ -337,16 +306,13 @@ config_monasca_ui
 config_murano_dashboard
 config_neutron_vpnaas_dashboard
 config_octavia_dashboard
-config_qinling_dashboard
 config_sahara_dashboard
-config_searchlight_ui
 config_senlin_dashboard
 config_solum_dashboard
 config_tacker_dashboard
 config_trove_dashboard
 config_vitrage_dashboard
 config_watcher_dashboard
-config_zaqar_dashboard
 config_zun_dashboard
 
 if settings_changed; then
