@@ -338,7 +338,7 @@ SOURCES = {
                      'glance-${openstack_branch}.tar.gz')},
     'gnocchi-base': {
         'type': 'git',
-        'reference': '4.4.0',
+        'reference': '4.4.1',
         'location': ('https://github.com/gnocchixyz/'
                      'gnocchi.git')},
     'heat-base': {
@@ -1043,6 +1043,11 @@ USERS = {
     'masakari-user': {
         'uid': 42485,
         'gid': 42485,
+    },
+    'hacluster-user': {
+        'uid': 42486,
+        'gid': 42486,
+        'group': 'haclient',
     }
 }
 
@@ -1058,10 +1063,11 @@ def get_source_opts(type_=None, location=None, reference=None):
                              'or branch name'))]
 
 
-def get_user_opts(uid, gid):
+def get_user_opts(uid, gid, group):
     return [
         cfg.IntOpt('uid', default=uid, help='The user id'),
         cfg.IntOpt('gid', default=gid, help='The group id'),
+        cfg.StrOpt('group', default=group, help='The group name'),
     ]
 
 
@@ -1069,7 +1075,11 @@ def gen_all_user_opts():
     for name, params in USERS.items():
         uid = params['uid']
         gid = params['gid']
-        yield name, get_user_opts(uid, gid)
+        try:
+            group = params['group']
+        except KeyError:
+            group = name[:-5]
+        yield name, get_user_opts(uid, gid, group)
 
 
 def gen_all_source_opts():
